From f4fae92b6768541e2952173c3d4b09040f95bf7e Mon Sep 17 00:00:00 2001
From: tpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>
Date: Wed, 16 Feb 2011 20:17:18 +0000
Subject: Moved kpilot from kdepim to applications, as the core Trinity
 libraries should not contain hardware-dependent software

git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1221127 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
---
 kmail/kmmsgdict.cpp | 28 ++++++++++++++--------------
 1 file changed, 14 insertions(+), 14 deletions(-)

(limited to 'kmail/kmmsgdict.cpp')

diff --git a/kmail/kmmsgdict.cpp b/kmail/kmmsgdict.cpp
index 8f9a9551c..07f5797d0 100644
--- a/kmail/kmmsgdict.cpp
+++ b/kmail/kmmsgdict.cpp
@@ -223,7 +223,7 @@ unsigned long KMMsgDict::insert(unsigned long msgSerNum,
     folder->setDirty( true ); // rewrite id file
   }
 
   // Insert into the dict. Don't use dict->replace() as we _know_
   // there is no entry with the same msn, we just made sure.
   KMMsgDictEntry *entry = new KMMsgDictEntry(folder->folder(), index);
   dict->insert((long)msn, entry);
@@ -246,12 +246,12 @@ unsigned long KMMsgDict::insert(const KMMsgBase *msg, int index)
 
 //-----------------------------------------------------------------------------
 
-void KMMsgDict::replace(unsigned long msgSerNum,
+void KMMsgDict::tqreplace(unsigned long msgSerNum,
 		       const KMMsgBase *msg, int index)
 {
   KMFolderIndex* folder = static_cast<KMFolderIndex*>( msg->storage() );
   if ( !folder ) {
-    kdDebug(5006) << "KMMsgDict::replace: Cannot replace the message serial "
+    kdDebug(5006) << "KMMsgDict::tqreplace: Cannot tqreplace the message serial "
       << "number, null pointer to storage. Requested serial: " << msgSerNum
       << endl;
     kdDebug(5006) << "  Message info: Subject: " << msg->subject() << ", To: "
@@ -411,14 +411,14 @@ int KMMsgDict::readFolderIds( FolderStorage& storage )
   }
 
   bool swapByteOrder;
-  Q_UINT32 byte_order;
+  TQ_UINT32 byte_order;
   if (!fread(&byte_order, sizeof(byte_order), 1, fp)) {
     fclose(fp);
     return -1;
   }
   swapByteOrder = (byte_order == 0x78563412);
 
-  Q_UINT32 count;
+  TQ_UINT32 count;
   if (!fread(&count, sizeof(count), 1, fp)) {
     fclose(fp);
     return -1;
@@ -434,7 +434,7 @@ int KMMsgDict::readFolderIds( FolderStorage& storage )
   fseek(fp, pos, SEEK_SET);   // back to previous position
 
   // the file must at least contain what we try to read below
-  if ( (fileSize - pos) < (long)(count * sizeof(Q_UINT32)) ) {
+  if ( (fileSize - pos) < (long)(count * sizeof(TQ_UINT32)) ) {
     fclose(fp);
     return -1;
   }
@@ -442,7 +442,7 @@ int KMMsgDict::readFolderIds( FolderStorage& storage )
   KMMsgDictREntry *rentry = new KMMsgDictREntry(count);
 
   for (unsigned int index = 0; index < count; index++) {
-    Q_UINT32 msn;
+    TQ_UINT32 msn;
 
     bool readOk = fread(&msn, sizeof(msn), 1, fp);
     if (swapByteOrder)
@@ -468,7 +468,7 @@ int KMMsgDict::readFolderIds( FolderStorage& storage )
       Q_ASSERT( msn != 0 );
     }
 
     // Insert into the dict. Don't use dict->replace() as we _know_
     // there is no entry with the same msn, we just made sure.
     KMMsgDictEntry *entry = new KMMsgDictEntry( storage.folder(), index);
     dict->insert((long)msn, entry);
@@ -506,7 +506,7 @@ KMMsgDictREntry *KMMsgDict::openFolderIds( const FolderStorage& storage, bool tr
       fscanf(fp, IDS_HEADER, &version);
       if (version == IDS_VERSION)
       {
-         Q_UINT32 byte_order = 0;
+         TQ_UINT32 byte_order = 0;
          fread(&byte_order, sizeof(byte_order), 1, fp);
          rentry->swapByteOrder = (byte_order == 0x78563412);
       }
@@ -530,7 +530,7 @@ KMMsgDictREntry *KMMsgDict::openFolderIds( const FolderStorage& storage, bool tr
          return 0;
       }
       fprintf(fp, IDS_HEADER, IDS_VERSION);
-      Q_UINT32 byteOrder = 0x12345678;
+      TQ_UINT32 byteOrder = 0x12345678;
       fwrite(&byteOrder, sizeof(byteOrder), 1, fp);
       rentry->swapByteOrder = false;
     }
@@ -552,7 +552,7 @@ int KMMsgDict::writeFolderIds( const FolderStorage &storage )
 
   fseek(fp, rentry->baseOffset, SEEK_SET);
   // kdDebug(5006) << "Dict writing for folder " << storage.label() << endl;
-  Q_UINT32 count = rentry->getRealSize();
+  TQ_UINT32 count = rentry->getRealSize();
   if (!fwrite(&count, sizeof(count), 1, fp)) {
     kdDebug(5006) << "Dict cannot write count with folder " << storage.label() << ": "
                   << strerror(errno) << " (" << errno << ")" << endl;
@@ -560,7 +560,7 @@ int KMMsgDict::writeFolderIds( const FolderStorage &storage )
   }
 
   for (unsigned int index = 0; index < count; index++) {
-    Q_UINT32 msn = rentry->getMsn(index);
+    TQ_UINT32 msn = rentry->getMsn(index);
     if (!fwrite(&msn, sizeof(msn), 1, fp))
       return -1;
     if ( msn == 0 ) {
@@ -605,7 +605,7 @@ int KMMsgDict::appendToFolderIds( FolderStorage& storage, int index)
 //  kdDebug(5006) << "Dict appending for folder " << storage.label() << endl;
 
   fseek(fp, rentry->baseOffset, SEEK_SET);
-  Q_UINT32 count;
+  TQ_UINT32 count;
   if (!fread(&count, sizeof(count), 1, fp)) {
     kdDebug(5006) << "Dict cannot read count for folder " << storage.label() << ": "
                   << strerror(errno) << " (" << errno << ")" << endl;
@@ -629,7 +629,7 @@ int KMMsgDict::appendToFolderIds( FolderStorage& storage, int index)
   if (ofs > 0)
     fseek(fp, ofs, SEEK_CUR);
 
-  Q_UINT32 msn = rentry->getMsn(index);
+  TQ_UINT32 msn = rentry->getMsn(index);
   if (rentry->swapByteOrder)
      msn = kmail_swap_32(msn);
   if (!fwrite(&msn, sizeof(msn), 1, fp)) {
@@ -223,7 +223,7 @@ unsigned long KMMsgDict::insert(unsigned long msgSerNum,
   }
 
-  // Insert into the dict. Don't use dict->replace() as we _know_
+  // Insert into the dict. Don't use dict->tqreplace() as we _know_
   // there is no entry with the same msn, we just made sure.
   KMMsgDictEntry *entry = new KMMsgDictEntry(folder->folder(), index);
@@ -468,7 +468,7 @@ int KMMsgDict::readFolderIds( FolderStorage& storage )
     }
 
-    // Insert into the dict. Don't use dict->replace() as we _know_
+    // Insert into the dict. Don't use dict->tqreplace() as we _know_
     // there is no entry with the same msn, we just made sure.
     KMMsgDictEntry *entry = new KMMsgDictEntry( storage.folder(), index);
-- 
cgit v1.2.1